/* 
 * Copyright (C) 2015 Martin Gräßlin
 * Copyright (C) 2015 Marco Martin
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BLUR_CLIENT_PROTOCOL_H
#define BLUR_CLIENT_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

struct wl_client;
struct wl_resource;

struct org_kde_kwin_blur_manager;
struct org_kde_kwin_blur;

extern const struct wl_interface org_kde_kwin_blur_manager_interface;
extern const struct wl_interface org_kde_kwin_blur_interface;

#define ORG_KDE_KWIN_BLUR_MANAGER_CREATE	0
#define ORG_KDE_KWIN_BLUR_MANAGER_UNSET	1

static inline void
org_kde_kwin_blur_manager_set_user_data(struct org_kde_kwin_blur_manager *org_kde_kwin_blur_manager, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) org_kde_kwin_blur_manager, user_data);
}

static inline void *
org_kde_kwin_blur_manager_get_user_data(struct org_kde_kwin_blur_manager *org_kde_kwin_blur_manager)
{
	return wl_proxy_get_user_data((struct wl_proxy *) org_kde_kwin_blur_manager);
}

static inline void
org_kde_kwin_blur_manager_destroy(struct org_kde_kwin_blur_manager *org_kde_kwin_blur_manager)
{
	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_blur_manager);
}

static inline struct org_kde_kwin_blur *
org_kde_kwin_blur_manager_create(struct org_kde_kwin_blur_manager *org_kde_kwin_blur_manager, struct wl_surface *surface)
{
	struct wl_proxy *id;

	id = wl_proxy_marshal_constructor((struct wl_proxy *) org_kde_kwin_blur_manager,
			 ORG_KDE_KWIN_BLUR_MANAGER_CREATE, &org_kde_kwin_blur_interface, NULL, surface);

	return (struct org_kde_kwin_blur *) id;
}

static inline void
org_kde_kwin_blur_manager_unset(struct org_kde_kwin_blur_manager *org_kde_kwin_blur_manager, struct wl_surface *surface)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_blur_manager,
			 ORG_KDE_KWIN_BLUR_MANAGER_UNSET, surface);
}

#define ORG_KDE_KWIN_BLUR_COMMIT	0
#define ORG_KDE_KWIN_BLUR_SET_REGION	1
#define ORG_KDE_KWIN_BLUR_RELEASE	2

static inline void
org_kde_kwin_blur_set_user_data(struct org_kde_kwin_blur *org_kde_kwin_blur, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) org_kde_kwin_blur, user_data);
}

static inline void *
org_kde_kwin_blur_get_user_data(struct org_kde_kwin_blur *org_kde_kwin_blur)
{
	return wl_proxy_get_user_data((struct wl_proxy *) org_kde_kwin_blur);
}

static inline void
org_kde_kwin_blur_destroy(struct org_kde_kwin_blur *org_kde_kwin_blur)
{
	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_blur);
}

static inline void
org_kde_kwin_blur_commit(struct org_kde_kwin_blur *org_kde_kwin_blur)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_blur,
			 ORG_KDE_KWIN_BLUR_COMMIT);
}

static inline void
org_kde_kwin_blur_set_region(struct org_kde_kwin_blur *org_kde_kwin_blur, struct wl_region *region)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_blur,
			 ORG_KDE_KWIN_BLUR_SET_REGION, region);
}

static inline void
org_kde_kwin_blur_release(struct org_kde_kwin_blur *org_kde_kwin_blur)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_blur,
			 ORG_KDE_KWIN_BLUR_RELEASE);

	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_blur);
}

#ifdef  __cplusplus
}
#endif

#endif
