/* 
 * Copyright (C) 2015 Martin Gräßlin
 * Copyright (C) 2015 Marco Martin
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONTRAST_CLIENT_PROTOCOL_H
#define CONTRAST_CLIENT_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

struct wl_client;
struct wl_resource;

struct org_kde_kwin_contrast_manager;
struct org_kde_kwin_contrast;

extern const struct wl_interface org_kde_kwin_contrast_manager_interface;
extern const struct wl_interface org_kde_kwin_contrast_interface;

#define ORG_KDE_KWIN_CONTRAST_MANAGER_CREATE	0
#define ORG_KDE_KWIN_CONTRAST_MANAGER_UNSET	1

static inline void
org_kde_kwin_contrast_manager_set_user_data(struct org_kde_kwin_contrast_manager *org_kde_kwin_contrast_manager, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) org_kde_kwin_contrast_manager, user_data);
}

static inline void *
org_kde_kwin_contrast_manager_get_user_data(struct org_kde_kwin_contrast_manager *org_kde_kwin_contrast_manager)
{
	return wl_proxy_get_user_data((struct wl_proxy *) org_kde_kwin_contrast_manager);
}

static inline void
org_kde_kwin_contrast_manager_destroy(struct org_kde_kwin_contrast_manager *org_kde_kwin_contrast_manager)
{
	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_contrast_manager);
}

static inline struct org_kde_kwin_contrast *
org_kde_kwin_contrast_manager_create(struct org_kde_kwin_contrast_manager *org_kde_kwin_contrast_manager, struct wl_surface *surface)
{
	struct wl_proxy *id;

	id = wl_proxy_marshal_constructor((struct wl_proxy *) org_kde_kwin_contrast_manager,
			 ORG_KDE_KWIN_CONTRAST_MANAGER_CREATE, &org_kde_kwin_contrast_interface, NULL, surface);

	return (struct org_kde_kwin_contrast *) id;
}

static inline void
org_kde_kwin_contrast_manager_unset(struct org_kde_kwin_contrast_manager *org_kde_kwin_contrast_manager, struct wl_surface *surface)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_contrast_manager,
			 ORG_KDE_KWIN_CONTRAST_MANAGER_UNSET, surface);
}

#define ORG_KDE_KWIN_CONTRAST_COMMIT	0
#define ORG_KDE_KWIN_CONTRAST_SET_REGION	1
#define ORG_KDE_KWIN_CONTRAST_SET_CONTRAST	2
#define ORG_KDE_KWIN_CONTRAST_SET_INTENSITY	3
#define ORG_KDE_KWIN_CONTRAST_SET_SATURATION	4
#define ORG_KDE_KWIN_CONTRAST_RELEASE	5

static inline void
org_kde_kwin_contrast_set_user_data(struct org_kde_kwin_contrast *org_kde_kwin_contrast, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) org_kde_kwin_contrast, user_data);
}

static inline void *
org_kde_kwin_contrast_get_user_data(struct org_kde_kwin_contrast *org_kde_kwin_contrast)
{
	return wl_proxy_get_user_data((struct wl_proxy *) org_kde_kwin_contrast);
}

static inline void
org_kde_kwin_contrast_destroy(struct org_kde_kwin_contrast *org_kde_kwin_contrast)
{
	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_contrast);
}

static inline void
org_kde_kwin_contrast_commit(struct org_kde_kwin_contrast *org_kde_kwin_contrast)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_contrast,
			 ORG_KDE_KWIN_CONTRAST_COMMIT);
}

static inline void
org_kde_kwin_contrast_set_region(struct org_kde_kwin_contrast *org_kde_kwin_contrast, struct wl_region *region)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_contrast,
			 ORG_KDE_KWIN_CONTRAST_SET_REGION, region);
}

static inline void
org_kde_kwin_contrast_set_contrast(struct org_kde_kwin_contrast *org_kde_kwin_contrast, wl_fixed_t contrast)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_contrast,
			 ORG_KDE_KWIN_CONTRAST_SET_CONTRAST, contrast);
}

static inline void
org_kde_kwin_contrast_set_intensity(struct org_kde_kwin_contrast *org_kde_kwin_contrast, wl_fixed_t intensity)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_contrast,
			 ORG_KDE_KWIN_CONTRAST_SET_INTENSITY, intensity);
}

static inline void
org_kde_kwin_contrast_set_saturation(struct org_kde_kwin_contrast *org_kde_kwin_contrast, wl_fixed_t saturation)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_contrast,
			 ORG_KDE_KWIN_CONTRAST_SET_SATURATION, saturation);
}

static inline void
org_kde_kwin_contrast_release(struct org_kde_kwin_contrast *org_kde_kwin_contrast)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_contrast,
			 ORG_KDE_KWIN_CONTRAST_RELEASE);

	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_contrast);
}

#ifdef  __cplusplus
}
#endif

#endif
