/* 
 * Copyright (C) 2015 Martin Gräßlin
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef FAKE_INPUT_CLIENT_PROTOCOL_H
#define FAKE_INPUT_CLIENT_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

struct wl_client;
struct wl_resource;

struct org_kde_kwin_fake_input;

extern const struct wl_interface org_kde_kwin_fake_input_interface;

#define ORG_KDE_KWIN_FAKE_INPUT_AUTHENTICATE	0
#define ORG_KDE_KWIN_FAKE_INPUT_POINTER_MOTION	1
#define ORG_KDE_KWIN_FAKE_INPUT_BUTTON	2
#define ORG_KDE_KWIN_FAKE_INPUT_AXIS	3

static inline void
org_kde_kwin_fake_input_set_user_data(struct org_kde_kwin_fake_input *org_kde_kwin_fake_input, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) org_kde_kwin_fake_input, user_data);
}

static inline void *
org_kde_kwin_fake_input_get_user_data(struct org_kde_kwin_fake_input *org_kde_kwin_fake_input)
{
	return wl_proxy_get_user_data((struct wl_proxy *) org_kde_kwin_fake_input);
}

static inline void
org_kde_kwin_fake_input_destroy(struct org_kde_kwin_fake_input *org_kde_kwin_fake_input)
{
	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_fake_input);
}

static inline void
org_kde_kwin_fake_input_authenticate(struct org_kde_kwin_fake_input *org_kde_kwin_fake_input, const char *application, const char *reason)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_fake_input,
			 ORG_KDE_KWIN_FAKE_INPUT_AUTHENTICATE, application, reason);
}

static inline void
org_kde_kwin_fake_input_pointer_motion(struct org_kde_kwin_fake_input *org_kde_kwin_fake_input, wl_fixed_t delta_x, wl_fixed_t delta_y)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_fake_input,
			 ORG_KDE_KWIN_FAKE_INPUT_POINTER_MOTION, delta_x, delta_y);
}

static inline void
org_kde_kwin_fake_input_button(struct org_kde_kwin_fake_input *org_kde_kwin_fake_input, uint32_t button, uint32_t state)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_fake_input,
			 ORG_KDE_KWIN_FAKE_INPUT_BUTTON, button, state);
}

static inline void
org_kde_kwin_fake_input_axis(struct org_kde_kwin_fake_input *org_kde_kwin_fake_input, uint32_t axis, wl_fixed_t value)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_fake_input,
			 ORG_KDE_KWIN_FAKE_INPUT_AXIS, axis, value);
}

#ifdef  __cplusplus
}
#endif

#endif
