/* 
 * Copyright (C) 2015 Martin Gräßlin
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SHADOW_CLIENT_PROTOCOL_H
#define SHADOW_CLIENT_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

struct wl_client;
struct wl_resource;

struct org_kde_kwin_shadow_manager;
struct org_kde_kwin_shadow;

extern const struct wl_interface org_kde_kwin_shadow_manager_interface;
extern const struct wl_interface org_kde_kwin_shadow_interface;

#define ORG_KDE_KWIN_SHADOW_MANAGER_CREATE	0
#define ORG_KDE_KWIN_SHADOW_MANAGER_UNSET	1

static inline void
org_kde_kwin_shadow_manager_set_user_data(struct org_kde_kwin_shadow_manager *org_kde_kwin_shadow_manager, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) org_kde_kwin_shadow_manager, user_data);
}

static inline void *
org_kde_kwin_shadow_manager_get_user_data(struct org_kde_kwin_shadow_manager *org_kde_kwin_shadow_manager)
{
	return wl_proxy_get_user_data((struct wl_proxy *) org_kde_kwin_shadow_manager);
}

static inline void
org_kde_kwin_shadow_manager_destroy(struct org_kde_kwin_shadow_manager *org_kde_kwin_shadow_manager)
{
	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_shadow_manager);
}

static inline struct org_kde_kwin_shadow *
org_kde_kwin_shadow_manager_create(struct org_kde_kwin_shadow_manager *org_kde_kwin_shadow_manager, struct wl_surface *surface)
{
	struct wl_proxy *id;

	id = wl_proxy_marshal_constructor((struct wl_proxy *) org_kde_kwin_shadow_manager,
			 ORG_KDE_KWIN_SHADOW_MANAGER_CREATE, &org_kde_kwin_shadow_interface, NULL, surface);

	return (struct org_kde_kwin_shadow *) id;
}

static inline void
org_kde_kwin_shadow_manager_unset(struct org_kde_kwin_shadow_manager *org_kde_kwin_shadow_manager, struct wl_surface *surface)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow_manager,
			 ORG_KDE_KWIN_SHADOW_MANAGER_UNSET, surface);
}

#define ORG_KDE_KWIN_SHADOW_COMMIT	0
#define ORG_KDE_KWIN_SHADOW_ATTACH_LEFT	1
#define ORG_KDE_KWIN_SHADOW_ATTACH_TOP_LEFT	2
#define ORG_KDE_KWIN_SHADOW_ATTACH_TOP	3
#define ORG_KDE_KWIN_SHADOW_ATTACH_TOP_RIGHT	4
#define ORG_KDE_KWIN_SHADOW_ATTACH_RIGHT	5
#define ORG_KDE_KWIN_SHADOW_ATTACH_BOTTOM_RIGHT	6
#define ORG_KDE_KWIN_SHADOW_ATTACH_BOTTOM	7
#define ORG_KDE_KWIN_SHADOW_ATTACH_BOTTOM_LEFT	8
#define ORG_KDE_KWIN_SHADOW_SET_LEFT_OFFSET	9
#define ORG_KDE_KWIN_SHADOW_SET_TOP_OFFSET	10
#define ORG_KDE_KWIN_SHADOW_SET_RIGHT_OFFSET	11
#define ORG_KDE_KWIN_SHADOW_SET_BOTTOM_OFFSET	12

static inline void
org_kde_kwin_shadow_set_user_data(struct org_kde_kwin_shadow *org_kde_kwin_shadow, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) org_kde_kwin_shadow, user_data);
}

static inline void *
org_kde_kwin_shadow_get_user_data(struct org_kde_kwin_shadow *org_kde_kwin_shadow)
{
	return wl_proxy_get_user_data((struct wl_proxy *) org_kde_kwin_shadow);
}

static inline void
org_kde_kwin_shadow_destroy(struct org_kde_kwin_shadow *org_kde_kwin_shadow)
{
	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_shadow);
}

static inline void
org_kde_kwin_shadow_commit(struct org_kde_kwin_shadow *org_kde_kwin_shadow)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_COMMIT);
}

static inline void
org_kde_kwin_shadow_attach_left(struct org_kde_kwin_shadow *org_kde_kwin_shadow, struct wl_buffer *buffer)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_ATTACH_LEFT, buffer);
}

static inline void
org_kde_kwin_shadow_attach_top_left(struct org_kde_kwin_shadow *org_kde_kwin_shadow, struct wl_buffer *buffer)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_ATTACH_TOP_LEFT, buffer);
}

static inline void
org_kde_kwin_shadow_attach_top(struct org_kde_kwin_shadow *org_kde_kwin_shadow, struct wl_buffer *buffer)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_ATTACH_TOP, buffer);
}

static inline void
org_kde_kwin_shadow_attach_top_right(struct org_kde_kwin_shadow *org_kde_kwin_shadow, struct wl_buffer *buffer)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_ATTACH_TOP_RIGHT, buffer);
}

static inline void
org_kde_kwin_shadow_attach_right(struct org_kde_kwin_shadow *org_kde_kwin_shadow, struct wl_buffer *buffer)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_ATTACH_RIGHT, buffer);
}

static inline void
org_kde_kwin_shadow_attach_bottom_right(struct org_kde_kwin_shadow *org_kde_kwin_shadow, struct wl_buffer *buffer)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_ATTACH_BOTTOM_RIGHT, buffer);
}

static inline void
org_kde_kwin_shadow_attach_bottom(struct org_kde_kwin_shadow *org_kde_kwin_shadow, struct wl_buffer *buffer)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_ATTACH_BOTTOM, buffer);
}

static inline void
org_kde_kwin_shadow_attach_bottom_left(struct org_kde_kwin_shadow *org_kde_kwin_shadow, struct wl_buffer *buffer)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_ATTACH_BOTTOM_LEFT, buffer);
}

static inline void
org_kde_kwin_shadow_set_left_offset(struct org_kde_kwin_shadow *org_kde_kwin_shadow, wl_fixed_t offset)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_SET_LEFT_OFFSET, offset);
}

static inline void
org_kde_kwin_shadow_set_top_offset(struct org_kde_kwin_shadow *org_kde_kwin_shadow, wl_fixed_t offset)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_SET_TOP_OFFSET, offset);
}

static inline void
org_kde_kwin_shadow_set_right_offset(struct org_kde_kwin_shadow *org_kde_kwin_shadow, wl_fixed_t offset)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_SET_RIGHT_OFFSET, offset);
}

static inline void
org_kde_kwin_shadow_set_bottom_offset(struct org_kde_kwin_shadow *org_kde_kwin_shadow, wl_fixed_t offset)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_shadow,
			 ORG_KDE_KWIN_SHADOW_SET_BOTTOM_OFFSET, offset);
}

#ifdef  __cplusplus
}
#endif

#endif
