/* 
 * Copyright (C) 2015 Martin Gräßlin
 * Copyright (C) 2015 Marco Martin
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONTRAST_SERVER_PROTOCOL_H
#define CONTRAST_SERVER_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

struct wl_client;
struct wl_resource;

struct org_kde_kwin_contrast_manager;
struct org_kde_kwin_contrast;

extern const struct wl_interface org_kde_kwin_contrast_manager_interface;
extern const struct wl_interface org_kde_kwin_contrast_interface;

struct org_kde_kwin_contrast_manager_interface {
	/**
	 * create - (none)
	 * @id: (none)
	 * @surface: (none)
	 */
	void (*create)(struct wl_client *client,
		       struct wl_resource *resource,
		       uint32_t id,
		       struct wl_resource *surface);
	/**
	 * unset - (none)
	 * @surface: (none)
	 */
	void (*unset)(struct wl_client *client,
		      struct wl_resource *resource,
		      struct wl_resource *surface);
};


struct org_kde_kwin_contrast_interface {
	/**
	 * commit - (none)
	 */
	void (*commit)(struct wl_client *client,
		       struct wl_resource *resource);
	/**
	 * set_region - (none)
	 * @region: (none)
	 */
	void (*set_region)(struct wl_client *client,
			   struct wl_resource *resource,
			   struct wl_resource *region);
	/**
	 * set_contrast - (none)
	 * @contrast: (none)
	 */
	void (*set_contrast)(struct wl_client *client,
			     struct wl_resource *resource,
			     wl_fixed_t contrast);
	/**
	 * set_intensity - (none)
	 * @intensity: (none)
	 */
	void (*set_intensity)(struct wl_client *client,
			      struct wl_resource *resource,
			      wl_fixed_t intensity);
	/**
	 * set_saturation - (none)
	 * @saturation: (none)
	 */
	void (*set_saturation)(struct wl_client *client,
			       struct wl_resource *resource,
			       wl_fixed_t saturation);
	/**
	 * release - release the contrast object
	 *
	 * 
	 */
	void (*release)(struct wl_client *client,
			struct wl_resource *resource);
};


#ifdef  __cplusplus
}
#endif

#endif
