/* 
 * Copyright (C) 2015 Martin Gräßlin
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef IDLE_SERVER_PROTOCOL_H
#define IDLE_SERVER_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

struct wl_client;
struct wl_resource;

struct org_kde_kwin_idle;
struct org_kde_kwin_idle_timeout;

extern const struct wl_interface org_kde_kwin_idle_interface;
extern const struct wl_interface org_kde_kwin_idle_timeout_interface;

/**
 * org_kde_kwin_idle - User idle time manager
 * @get_idle_timeout: (none)
 *
 * This interface allows to monitor user idle time on a given seat. The
 * interface allows to register timers which trigger when for the specified
 * time no user activity was registered on the seat and in addition it
 * notifies when user activity resumes.
 *
 * This is useful for applications wanting to perform actions when the user
 * is not interacting with the system, e.g. chat applications setting the
 * user as away, power management features to dim screen, etc.
 */
struct org_kde_kwin_idle_interface {
	/**
	 * get_idle_timeout - (none)
	 * @id: (none)
	 * @seat: (none)
	 * @timeout: (none)
	 */
	void (*get_idle_timeout)(struct wl_client *client,
				 struct wl_resource *resource,
				 uint32_t id,
				 struct wl_resource *seat,
				 uint32_t timeout);
};


struct org_kde_kwin_idle_timeout_interface {
	/**
	 * release - release the timeout object
	 *
	 * 
	 */
	void (*release)(struct wl_client *client,
			struct wl_resource *resource);
	/**
	 * simulate_user_activity - Simulates user activity for this
	 *	timeout. Should behave just like some real activity on the seat
	 *
	 * 
	 */
	void (*simulate_user_activity)(struct wl_client *client,
				       struct wl_resource *resource);
};

#define ORG_KDE_KWIN_IDLE_TIMEOUT_IDLE	0
#define ORG_KDE_KWIN_IDLE_TIMEOUT_RESUMED	1

#define ORG_KDE_KWIN_IDLE_TIMEOUT_IDLE_SINCE_VERSION	1
#define ORG_KDE_KWIN_IDLE_TIMEOUT_RESUMED_SINCE_VERSION	1

static inline void
org_kde_kwin_idle_timeout_send_idle(struct wl_resource *resource_)
{
	wl_resource_post_event(resource_, ORG_KDE_KWIN_IDLE_TIMEOUT_IDLE);
}

static inline void
org_kde_kwin_idle_timeout_send_resumed(struct wl_resource *resource_)
{
	wl_resource_post_event(resource_, ORG_KDE_KWIN_IDLE_TIMEOUT_RESUMED);
}

#ifdef  __cplusplus
}
#endif

#endif
