/* 
 * Copyright © 2015 Sebastian Kügler <sebas@kde.org>
 * Copyright © 2008-2011 Kristian Høgsberg
 * Copyright © 2010-2011 Intel Corporation
 * Copyright © 2012-2013 Collabora, Ltd.
 * 
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that the above copyright notice appear in
 * all copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of
 * the copyright holders not be used in advertising or publicity
 * pertaining to distribution of the software without specific,
 * written prior permission.  The copyright holders make no
 * representations about the suitability of this software for any
 * purpose.  It is provided "as is" without express or implied
 * warranty.
 * 
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 */

#ifndef ORG_KDE_KWIN_OUTPUTDEVICE_SERVER_PROTOCOL_H
#define ORG_KDE_KWIN_OUTPUTDEVICE_SERVER_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

struct wl_client;
struct wl_resource;

struct org_kde_kwin_outputdevice;

extern const struct wl_interface org_kde_kwin_outputdevice_interface;

#ifndef ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_ENUM
#define ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_ENUM
/**
 * org_kde_kwin_outputdevice_subpixel - subpixel geometry information
 * @ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_UNKNOWN: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_NONE: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_HORIZONTAL_RGB: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_HORIZONTAL_BGR: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_VERTICAL_RGB: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_VERTICAL_BGR: (none)
 *
 * This enumeration describes how the physical pixels on an output are
 * laid out.
 */
enum org_kde_kwin_outputdevice_subpixel {
	ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_UNKNOWN = 0,
	ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_NONE = 1,
	ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_HORIZONTAL_RGB = 2,
	ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_HORIZONTAL_BGR = 3,
	ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_VERTICAL_RGB = 4,
	ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_VERTICAL_BGR = 5,
};
#endif /* ORG_KDE_KWIN_OUTPUTDEVICE_SUBPIXEL_ENUM */

#ifndef ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_ENUM
#define ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_ENUM
/**
 * org_kde_kwin_outputdevice_transform - transform from framebuffer to
 *	output
 * @ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_NORMAL: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_90: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_180: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_270: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_FLIPPED: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_FLIPPED_90: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_FLIPPED_180: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_FLIPPED_270: (none)
 *
 * This describes the transform that a compositor will apply to a surface
 * to compensate for the rotation or mirroring of an output device.
 *
 * The flipped values correspond to an initial flip around a vertical axis
 * followed by rotation.
 *
 * The purpose is mainly to allow clients render accordingly and tell the
 * compositor, so that for fullscreen surfaces, the compositor will still
 * be able to scan out directly from client surfaces.
 */
enum org_kde_kwin_outputdevice_transform {
	ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_NORMAL = 0,
	ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_90 = 1,
	ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_180 = 2,
	ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_270 = 3,
	ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_FLIPPED = 4,
	ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_FLIPPED_90 = 5,
	ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_FLIPPED_180 = 6,
	ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_FLIPPED_270 = 7,
};
#endif /* ORG_KDE_KWIN_OUTPUTDEVICE_TRANSFORM_ENUM */

#ifndef ORG_KDE_KWIN_OUTPUTDEVICE_MODE_ENUM
#define ORG_KDE_KWIN_OUTPUTDEVICE_MODE_ENUM
/**
 * org_kde_kwin_outputdevice_mode - mode information
 * @ORG_KDE_KWIN_OUTPUTDEVICE_MODE_CURRENT: indicates this is the current
 *	mode
 * @ORG_KDE_KWIN_OUTPUTDEVICE_MODE_PREFERRED: indicates this is the
 *	preferred mode
 *
 * These flags describe properties of an output mode. They are used in
 * the flags bitfield of the mode event.
 */
enum org_kde_kwin_outputdevice_mode {
	ORG_KDE_KWIN_OUTPUTDEVICE_MODE_CURRENT = 0x1,
	ORG_KDE_KWIN_OUTPUTDEVICE_MODE_PREFERRED = 0x2,
};
#endif /* ORG_KDE_KWIN_OUTPUTDEVICE_MODE_ENUM */

#ifndef ORG_KDE_KWIN_OUTPUTDEVICE_ENABLEMENT_ENUM
#define ORG_KDE_KWIN_OUTPUTDEVICE_ENABLEMENT_ENUM
/**
 * org_kde_kwin_outputdevice_enablement - device is used to display
 *	content by the compositor
 * @ORG_KDE_KWIN_OUTPUTDEVICE_ENABLEMENT_DISABLED: (none)
 * @ORG_KDE_KWIN_OUTPUTDEVICE_ENABLEMENT_ENABLED: (none)
 *
 * Describes whether a device is enabled, i.e. device is used to display
 * content by the compositor. This wraps a boolean around an int to avoid a
 * boolean trap.
 */
enum org_kde_kwin_outputdevice_enablement {
	ORG_KDE_KWIN_OUTPUTDEVICE_ENABLEMENT_DISABLED = 0,
	ORG_KDE_KWIN_OUTPUTDEVICE_ENABLEMENT_ENABLED = 1,
};
#endif /* ORG_KDE_KWIN_OUTPUTDEVICE_ENABLEMENT_ENUM */

#define ORG_KDE_KWIN_OUTPUTDEVICE_GEOMETRY	0
#define ORG_KDE_KWIN_OUTPUTDEVICE_MODE	1
#define ORG_KDE_KWIN_OUTPUTDEVICE_DONE	2
#define ORG_KDE_KWIN_OUTPUTDEVICE_SCALE	3
#define ORG_KDE_KWIN_OUTPUTDEVICE_EDID	4
#define ORG_KDE_KWIN_OUTPUTDEVICE_ENABLED	5
#define ORG_KDE_KWIN_OUTPUTDEVICE_UUID	6

#define ORG_KDE_KWIN_OUTPUTDEVICE_GEOMETRY_SINCE_VERSION	1
#define ORG_KDE_KWIN_OUTPUTDEVICE_MODE_SINCE_VERSION	1
#define ORG_KDE_KWIN_OUTPUTDEVICE_DONE_SINCE_VERSION	1
#define ORG_KDE_KWIN_OUTPUTDEVICE_SCALE_SINCE_VERSION	1
#define ORG_KDE_KWIN_OUTPUTDEVICE_EDID_SINCE_VERSION	1
#define ORG_KDE_KWIN_OUTPUTDEVICE_ENABLED_SINCE_VERSION	1
#define ORG_KDE_KWIN_OUTPUTDEVICE_UUID_SINCE_VERSION	1

static inline void
org_kde_kwin_outputdevice_send_geometry(struct wl_resource *resource_, int32_t x, int32_t y, int32_t physical_width, int32_t physical_height, int32_t subpixel, const char *make, const char *model, int32_t transform)
{
	wl_resource_post_event(resource_, ORG_KDE_KWIN_OUTPUTDEVICE_GEOMETRY, x, y, physical_width, physical_height, subpixel, make, model, transform);
}

static inline void
org_kde_kwin_outputdevice_send_mode(struct wl_resource *resource_, uint32_t flags, int32_t width, int32_t height, int32_t refresh, int32_t mode_id)
{
	wl_resource_post_event(resource_, ORG_KDE_KWIN_OUTPUTDEVICE_MODE, flags, width, height, refresh, mode_id);
}

static inline void
org_kde_kwin_outputdevice_send_done(struct wl_resource *resource_)
{
	wl_resource_post_event(resource_, ORG_KDE_KWIN_OUTPUTDEVICE_DONE);
}

static inline void
org_kde_kwin_outputdevice_send_scale(struct wl_resource *resource_, int32_t factor)
{
	wl_resource_post_event(resource_, ORG_KDE_KWIN_OUTPUTDEVICE_SCALE, factor);
}

static inline void
org_kde_kwin_outputdevice_send_edid(struct wl_resource *resource_, const char *raw)
{
	wl_resource_post_event(resource_, ORG_KDE_KWIN_OUTPUTDEVICE_EDID, raw);
}

static inline void
org_kde_kwin_outputdevice_send_enabled(struct wl_resource *resource_, int32_t enabled)
{
	wl_resource_post_event(resource_, ORG_KDE_KWIN_OUTPUTDEVICE_ENABLED, enabled);
}

static inline void
org_kde_kwin_outputdevice_send_uuid(struct wl_resource *resource_, const char *uuid)
{
	wl_resource_post_event(resource_, ORG_KDE_KWIN_OUTPUTDEVICE_UUID, uuid);
}

#ifdef  __cplusplus
}
#endif

#endif
